<?php
namespace Drupal\scenarios\Commands;

use Drupal\scenarios\ScenariosHandler;
use Drush\Commands\DrushCommands;

class ScenariosCommands extends DrushCommands {

  /**
   * Drupal\scenarios\ScenariosHandler.
   *
   * @var \Drupal\scenarios\ScenariosHandler
   */
  protected $scenariosHandler;

  /**
   * ScenariosCommands constructor.
   *
   * @param \Drupal\scenarios\ScenariosHandler $scenarios_handler
   *   The update manager service.
   */
  public function __construct(ScenariosHandler $scenarios_handler) {
    $this->scenariosHandler = $scenarios_handler;
  }

  /**
   * Enables a scenario.
   *
   * @command scenarios:enable
   * @param string $scenario
   *   The name of the module that defines the scenario.
   * @usage es dfs_tec
   *   Install and import migrations for a scenario.
   * @aliases enable-scenario,es
   */
  public function enable($scenario) {
    $this->scenariosHandler->scenarioEnable($scenario);
  }

  /**
   * Uninstalls a scenario.
   *
   * @command scenarios:uninstall
   * @param string $scenario
   *   The name of the module that defines the scenario.
   * @usage us dfs_tec
   *   Uninstall and roll back migrations for a scenario.
   * @aliases uninstall-scenario,us
   */
  public function uninstall($scenario) {
    $this->scenariosHandler->scenarioUninstall($scenario);
  }

  /**
   * Resets a scenario.
   *
   * @command scenarios:reset
   * @param string $scenario
   *   The name of the module that defines the scenario.
   * @param array $options
   *   (optional) An array of options.
   * @option skip
   *   Skip aspects of the reset allowing migrations or the module to persist as-is.
   * @usage res dfs_tec
   *   Rolls back content then uninstalls and re-enables scenario for a clean reset.
   * @usage res dfs_tec --skip=modules
   *   Resets content by rolling back and importing scenario migrations only.
   * @usage res dfs_tec --skip=migrations
   *   Uninstalls and re-enables the scenario module, skipping migration rollback and import.
   * @aliases reset-scenario,res
   */
  public function reset($scenario, array $options = ['skip' => NULL]) {
    $skip = $options['skip'];
    $this->scenariosHandler->scenarioReset($scenario, $skip);
  }

}
